@@ -5,15 +5,15 @@
 #' @export
 versions <- function() {
   rlang::set_names(
-    list("4", "3"),
-    c(version_bs4, version_bs3)
+    list("5", "4", "3"),
+    c(version_bs5, version_bs4, version_bs3)
   )
 }
 
 #' @export
 #' @rdname versions
 version_default <- function() {
-  versions()[[1]]
+  versions()[[2]]
 }
 
 # TODO: make this a getter/setter?
